% close all
clear all
clc
%%
printFigs = false;

svnDir = '/ligo/svncommon/SusSVN/sus/trunk/';
modelDir = [svnDir 'QUAD/Common/MatlabTools/QuadModel_Production/'];
resultsDir = [svnDir 'Common/ModelPlayground/'];

quadType = 'erm';
includeMeas = true;
includeModel = true;

figTag = ['2012-10-23_' quadType];

modelColorTable = [0.0 0.0 1.0;...
                   1.0 0.0 0.0;...
                   1.0 1.0 0.0];
meastColorTable = [0.0 0.0 0.0;...
                   1.0 0.6 0.0;...
                   0.5 0.0 0.8;...
                   0.0 0.7 0.0];

switch quadType
    case 'fiber'
        sagLevel = 'M0';
        buildType{1} = 'fiber';
%         data(1).fileName = [svnDir 'BSFM/H2/FMY/SAGM1/Results/2012-02-15_1519_H2SUSFMY_M1'];
%         data(2).fileName = [svnDir 'BSFM/X2/BSFM06/BUILD01/SAGM1/Results/2012-01-27_X2SUSBSFM06_M1_MATTF'];
%         data(3).fileName = [svnDir 'BSFM/X2/BSFM06/BUILD01/SAGM1/Results/2012-02-29_X2SUSBSFM06_M1_MATTF'];
    case 'wire'
        sagLevel = 'M0';
        buildType{1} = 'wire';
        buildType{2} = 'wire_d3d4minusflex3';
        data(1).fileName = [svnDir 'QUAD/H2/ITMY/SAGM0/Results/2011_08_25_H2SUSITMY_M0_MATTF'];                  % Should be 'wire'
        data(2).fileName = [svnDir 'QUAD/X1/QUAD04/BUILD03/SAGM0/Results/2011-11-22_X1SUSQUAD04_M0_MATTF'];      % Should be 'wire'
        data(3).fileName = [svnDir 'QUAD/L1/ITMY/SAGM0/Results/2012-09-08_L1SUSITMY_M0_wire_model_MATTF'];       % Should be 'wire'
        
        data(1).config = 'Metal, Wire';
        data(2).config = 'Metal, Wire';
        data(3).config = 'Metal, Wire';
    case 'erm'
        sagLevel = 'R0';
        buildType{1} = 'erm';
        buildType{2} = 'erm_d4physical';
        data(1).fileName = [svnDir 'QUAD/X1/QUAD03/BUILD03/SAGR0/Results/2012-01-06_X1SUSQUAD03_R0'];       % (Metal, No Lacing Cables)
        data(2).fileName = [svnDir 'QUAD/X1/QUAD04/BUILD03/SAGR0/Results/2011-11-15_X1SUSQUAD04_R0_DTTTF']; % (Metal, No Lacing Cables)
%         data(3).fileName = [svnDir 'QUAD/X1/QUAD03/BUILD03/SAGR0/Results/2012-01-24_X1SUSQUAD03_R0_MATTF']; % (Metal, With Lacing Cables)
%         data(4).fileName = [svnDir 'QUAD/H2/ETMY/SAGR0/Results/2012-05-25_H2SUSETMY_R0_erm_model_MATTF'];   % (Glass, Full Lacing Cables)
        
        data(1).config = 'Metal, No Cables';
        data(2).config = 'Metal, No Cables';
%         data(3).config = 'Metal, With Cables';
%         data(4).config = 'Glass, With Cables';
    case 'thincp'
        sagLevel = 'R0';
        buildType{1} = 'thincp';
        buildType{2} = 'thincp_20120831';
        data(1).fileName = [svnDir 'QUAD/X2/QUAD11/BUILD01/SAGR0/Results/2011-07-31_X2SUSQUAD11_R0'];        % (Metal, No Lacing Cables)
        data(2).fileName = [svnDir 'QUAD/H2/ITMY/SAGR0/Results/2012-05-29_H2SUSITMY_R0_thincp_model_MATTF']; % (Glass, With Lacing Cables)
        
        data(1).config = 'Metal, No Cables';
        data(2).config = 'Glass, With Cables';
end

%%
slashInds = regexp(data(1).fileName,'/');
data(1).legName  = data(1).fileName((slashInds(end)+1):end);

for iModel = 1:length(buildType)
    modelLegs{iModel} = ['Model (' buildType{iModel} ')'];
end
for iMeas = 1:length(data)
    slashInds = regexp(data(iMeas).fileName,'/');
    sagInds = regexp(data(iMeas).fileName,sagLevel);
    data(iMeas).legName  = [data(iMeas).fileName((slashInds(end)+1):(sagInds(end)-2)) ', ' data(iMeas).config];
    dataLegs{iMeas} = ['Meas (' data(iMeas).legName ')'];
end
theLegend = [modelLegs,dataLegs];

dofs = {'L';'T';'V';'R';'P';'Y'};

freqRange = [1e-1 1e1];
freq = logspace(-2,2,2000);

%% Get Measurements, if possible

for iMeas = 1:length(data)
    cheese = load([data(iMeas).fileName '.mat']);
    for iExcDOF = 1:6
        for iRespDOF = 1:6
            meas(iMeas).eul2eul(iRespDOF,iExcDOF).f = cheese.meas.eul2eul(iRespDOF,iExcDOF).f;
        end
    end
    meas(iMeas).freq = cheese.meas.freq;
end

%%
for iModel = 1:length(buildType)
    [quad(iModel).model, in,  out,quad(iModel).pend] = generate_Quad_Model_Production(freq,buildType{iModel},svnDir,false); %#ok<*SAGROW>
    quad(iModel).fields = fieldnames(quad(iModel).pend);
end

changedParams = {'Param','Former Production Value','Updated Value','Differnce','Difference';...
                 ''     ,['Model: ' buildType{1}],['Model: ' buildType{2}],'(Absolute)','(Percent)'};

iCount = 3;
for iModel = 2:length(quad);
    for iField = 1:length(quad(iModel).fields);
        if ~ischar(quad(iModel).pend.(quad(iModel).fields{iField,:})) && isfield(quad(1).pend,quad(iModel).fields{iField,:})
            diff = quad(iModel).pend.(quad(iModel).fields{iField,:}) - quad(1).pend.(quad(iModel).fields{iField,:});
            if diff ~= 0
                changedParams{iCount,1} = quad(iModel).fields{iField,:};
                changedParams{iCount,2} = num2str(quad(1).pend.(quad(iModel).fields{iField,:}),3);
                changedParams{iCount,3} = num2str(quad(iModel).pend.(quad(iModel).fields{iField,:}),3);
                changedParams{iCount,4} = num2str(diff);
                changedParams{iCount,5} = [num2str(100*diff/quad(1).pend.(quad(iModel).fields{iField,:}),3) '%'];
                iCount = iCount+1;
            end
        else
            continue
        end
    end
end
changedParams

%%
plotNums = [1:6];

nModels = length(quad);
nMeasts = length(meas);

yLimits = [1e-6 1e-1;...
           1e-6 1e0;...
           1e-6 1e-1;...
           1e-4 1e1;...
           1e-3 1e2;...
           1e-4 1e1];
units = {'m/N';...
         'm/N';...
         'm/N';...
         'rad/N.m';...
         'rad/N.m';...
         'rad/N.m'};       


% for iDOF = plotNums;
for iDOF = 5;
    plotCommand = ['ll=loglog('];
    
    if includeModel
        for iModel = 1:nModels;
            eul2eul(iModel,iDOF).f = squeeze(quad(iModel).model.f(out.top.disp.(dofs{iDOF}),in.top.drive.(dofs{iDOF}),:));
            
            plotCommand = [plotCommand 'freq,abs(eul2eul(' num2str(iModel) ',iDOF).f),'];
        end
    end
    if includeMeas
        for iMeas = 1:nMeasts;
            plotCommand = [plotCommand 'meas(' num2str(iMeas) ').freq,abs(meas(' num2str(iMeas) ').eul2eul(iDOF,iDOF).f),'];
        end
    end
    plotCommand = [plotCommand(1:end-1) ');'];
        
    
    figure(iDOF)
    eval(plotCommand)
    title({[upper(quadType) ' Chains'];[sagLevel ' ' dofs{iDOF} ' to ' dofs{iDOF}]})
    for iModelLine = 1:nModels;set(ll(iModelLine),'Color',modelColorTable(iModelLine,:),'LineWidth',4);end
    for iMeastLine = 1:nMeasts;set(ll(iMeastLine+nModels),'Color',meastColorTable(iMeastLine,:),'LineWidth',2);end
    xlabel('Frequency (Hz)')
    ylabel(['Magnitude [' units{iDOF} ']'])
    xlim(freqRange)
    ylim(yLimits(iDOF,:))
    set(gca,'XTick',10.^(-1:1))
    set(gca,'YTick',10.^(log10(yLimits(iDOF,1)):log10(yLimits(iDOF,2))))
    set(gcf,'Position',[200*(iDOF-1) 200-30*(iDOF-1) 900 700])
    leg = legend(theLegend,'Location','SouthWest');
    set(leg,'Interpreter','None')
    set(leg,'FontSize',16)
    grid on
    
    if printFigs
        figs(iDOF).fileName = [resultsDir figTag 'quadmodelcomp_' sagLevel '_' dofs{iDOF} '2' dofs{iDOF} '.pdf'];
        figure(iDOF)
        FillPage('w')
        IDfig
        saveas(gcf,figs(iDOF).fileName)
    end
end

%%
if printFigs
    mergeCommand = ['pdfmerge ' resultsDir figTag 'quadmodelcomp_' sagLevel '.pdf'];
    for iDOF = plotNums
        mergeCommand = [mergeCommand ' ' figs(iDOF).fileName];
    end
    system(mergeCommand);
end

