%function[pend] = quadopt
global pend

% Corresponds to case 20060509controlsmainasbuiltsym of model mbquadlite2lateral
% For use with matrix elements ssmake4pv2eMB4.m/symbexport4lat.m of 5/9/06 or later.
% An approximation to the as-built controls prototype (10/11/05 build, main chain).
% Same as 20060331asbuiltsym but with measured masses from T040229-12 
% and blade spring constants recomputed directly from bounce mode frequencies. 
% All as-built numbers except off-diagonal MOI components are zeroed.

%**************************************************************************
%Updated to include Metal Quad NP values at LASTI.
%
%Locations of referenced documents with no DCC #:
% "As Designed Parameter Set 2" -
%   http://www.eng-external.rl.ac.uk/advligo/Reviews/FRR/Documents/As%20designed%20parameter%20set2.pdf
% "Useful data for Noise Prototype Quad assembly" -
%   http://www.eng-external.rl.ac.uk/advligo/documents/Useful%20data%20for%20Noise%20Prototype%20Quad%20assembly.pdf
%
%Brett Shapiro June 2008
%**************************************************************************
%Updated to correspond to reaction chain glass with wire configuration
% Still needs updated moments of inertia for round masses.
%
%Brett Shapiro Feb 2009
%**************************************************************************
% First effort to get a 'real' production model.
% Updated the file name to reflect today's date -
% quadopt20111121productionmainasbuiltoffdiag_fiber.m
%
% Parameters that still need updating as of 22 November 2011
% l3
% m1, m2, m3
%
% Brett Shapiro and Mark Barton
% 22 November 2011
%
% Tweaks by Brett and Jeff K, 6/1/12
%
% Mark Barton, 8/31/12
% Reverted sign flips in off-diagonal MOI terms that had been put in on the assumption that Joe had used the left-handed coordinate system of T040072.
% But Joe can't have used T040072 or Inxy and I1xy would have been positive not negative. 
% Rethought correction for the fact that on p25 (but only p25) of T1000286-v9, Joe has used a coordinate system with x and z swapped. *)
% Joe's Iyz is negative, which is expected sign for SUS I1xy, so his y, z must be SUS +y, +x 
% Assuming Joe's CS is still right handed, Joe's x, y, z must be SUS -z, +y, +x.
% Fix: swap Joe's x and z and then flip (SUS) yz and zx. 
% Weeded out some numbers left over from UIM w/o pitch adjuster.

                        pend.version = 'mark.barton/20120831TMproductionCP';
                              pend.g = 9.81;
                             pend.nx = 0.1300; % T040214-01 
                             pend.ny = 0.5000; % T040214-01 
                             pend.nz = 0.0840; % T040214-01 
                           pend.denn = 4000; % T040214-01 (unused)
                             pend.mn = 22.002; % measured value listed in E1000186_v18_QUAD-2_Process_Traveler
                            pend.Inx = 0.46117648;  % T1000286-v9 11.2 Reaction Top Mass
                            pend.Iny = 0.074251818; % T1000286-v9 11.2 Reaction Top Mass
                            pend.Inz = 0.47263418;  % T1000286-v9 11.2 Reaction Top Mass
                            pend.Inxy = -0.037561070; % T1000286-v9, 11.2 Reaction Top Mass
                            pend.Inyz = -4.3598626e-5; % T1000286-v9, 11.2 Reaction Top Mass
                            pend.Inzx = 0.0017139341;% T1000286-v9, 11.2 Reaction Top Mass
                            
                             pend.ux = 0.1300; % T040214-01 
                             pend.uy = 0.5000; % T040214-01 
                             pend.uz = 0.0840; % T040214-01 
                           pend.den1 = 4000; % T040214-01  (unused)
                             pend.m1 = 21.532; % measured value listed in E1000186_v18_QUAD-2_Process_Traveler
                            pend.I1x = 0.50521954; % T1000286-v9 11.6 Reaction UIM with pitch adjuster, Joe's zz
                            pend.I1y = 0.073433036;% T1000286-v9 11.6 Reaction UIM with pitch adjuster, Joe's yy
                            pend.I1z = 0.51817090; % T1000286-v9 11.6 Reaction UIM with pitch adjuster, Joe's xx
                            pend.I1xy =  -0.013211797; % T1000286-v9 11.6 Reaction UIM with pitch adjuster
                            pend.I1yz =  5.0102707e-05;% T1000286-v9 11.6 Reaction UIM with pitch adjuster
                            pend.I1zx =  3.4120911e-05;% T1000286-v9 11.6 Reaction UIM with pitch adjuster
                            
                             pend.ix = 0.1300; % T040214-01 
                             pend.ir = 0.17;
                           pend.den2 = 3860; % T040214-01 (unused)
                             pend.m2 = 59.229; % ITM value not listed in measured value listed in E1000186_v18_QUAD-2_Process_Traveler. Calculated from ETM values listed in E1000186_v18_QUAD-2_Process_Traveler by pend.m2 = 26.130+53.138-20.039
                            pend.I2x = 0.92327494; % T1000286-v9 11.8 Penultimate Reaction Mass (ITM)
                            pend.I2y = 0.53557103; % T1000286-v9 11.8 Penultimate Reaction Mass (ITM)
                            pend.I2z = 0.52347974; % T1000286-v9 11.8 Penultimate Reaction Mass (ITM)
                            pend.I2xy = -5.8708519e-5;% T1000286-v9, 11.8 Penultimate Reaction Mass (ITM)
                            pend.I2yz = 2.3761318e-5; % T1000286-v9, 11.8 Penultimate Reaction Mass (ITM)
                            pend.I2zx = 4.4074302e-5; % T1000286-v9, 11.8 Penultimate Reaction Mass (ITM)
                            
                             pend.tx = 0.10032; % C1000458
                             pend.tr = 0.34011/2; % C1000458
                           pend.den3 = 2200; % unused
                             pend.m3 = 20.039; % measured value listed in E1000186_v18_QUAD-2_Process_Traveler
                            pend.I3x = 0.2898; % pend.I3x = 0.5*pend.m3*pend.tr^2
                            pend.I3y = 0.1617; % pend.I3y = (1/12)*pend.m*(3*pend.tr^2 + pend.tx^2)
%                             pend.I3z = 0.396568; % D060355-D; BNS 6/18/08
                            pend.I3z = 0.1617; % pend.I3z = (1/12)*pend.m*(3*pend.tr^2 + pend.tx^2)
                            pend.I3xy = 0;
                            pend.I3yz = 0;
                            pend.I3zx = 0;                            

                            pend.ln = 0.449192; % Mark Barton, 11/22/2011
                            pend.l1 = 0.308585; % Mark Barton, 11/22/2011
                            pend.l2 = 0.330787; % Mark Barton, 11/22/2011
                            pend.l3 = 0.60406;  % Mark Barton, 11/22/2011
                            
                            pend.nwn = 2; 
                            pend.nw1 = 4; 
                            pend.nw2 = 4;
                            pend.nw3 = 4; 
                            
                             pend.bd = 0.001; % Damping - BNS 6/24/2008
                             
                             pend.rn = (1.1/2)*10^-03; % "Useful data for Noise Prototype Quad assembly"; BNS 6/18/08
                             pend.r1 = (0.71/2)*10^-03; % "Useful data for Noise Prototype Quad assembly"; BNS 6/18/08
                             pend.r2 = (0.635/2)*10^-03; % "Useful data for Noise Prototype Quad assembly"; BNS 6/18/08
                             pend.r3 = (0.457/2)*10^-03; % "Useful data for Noise Prototype Quad assembly"; BNS 6/18/08%     
                                       
                             pend.Yn = 2.12000*10^+11; % "As Designed Parameter Set 2"; BNS 6/18/08
                             pend.Y1 = 2.12000*10^+11; % "As Designed Parameter Set 2"; BNS 6/18/08
                             pend.Y2 = 2.12000*10^+11; % "As Designed Parameter Set 2"; BNS 6/18/08
                             pend.Y3 = 2.12000*10^+11; % BNS 6/18/08
%                              pend.Y3 = 7.2*10^10; % For Silica Fibers. Peter Fritschel 11/11/2008

                    pend.twistlength = 0; 				% T040214-01 
                           pend.d3tr = 1.0000*10^-03;	% T040214-01 
                           pend.d4tr = 1.0000*10^-03;	% T040214-01 
                           
                             pend.sn = 0; 				% T040214-01 
                             pend.su = 0.003;  % T040214-01 
                             pend.si = 0.003;  % T040214-01 
                             pend.sl = 0.015;  % T040214-01 
                             
                            pend.nn0 = 0.250;  % T040214-01 
                            pend.nn1 = 0.090;  % T040214-01 
                             pend.n0 = 0.200;  % T040214-01 
                             pend.n1 = 0.060;  % T040214-01 
                             pend.n2 = 0.140;  % T040214-01 
                             pend.n3 = 0.1762; % CT, email to NR, 9/22/04 
                             pend.n4 = 0.1712; % CT, email to NR, 9/22/04 
                             pend.n5 = 0.1712; % CT, email to NR, 9/22/04 
                             
                                 sin = (pend.nn1-pend.nn0)/pend.ln;
                                 si1 = (pend.n1-pend.n0)/pend.l1;
                                 si2 = (pend.n3-pend.n2)/pend.l2;
                                 si3 = (pend.n5-pend.n4)/pend.l3;	
                                 
                                 ffn = 0.807; % from Ian's data, 11/30/05 
                                 ff1 = 0.641; % from Ian's data, 11/30/05 
                                 ff2 = 0.608; % from Ian's data, 11/30/05 
                                kffn = 1 + ffn*tan(asin(sin));
                                kff1 = 1 + ff1*tan(asin(si1));
                                kff2 = 1 + ff2*tan(asin(si2));
                                
%                           % Given values: "As Designed Parameter Set 2" BNS 6/18/08 
%                           pend.kcn = 1611.1; % 
% 							pend.kc1 = 1811.4;
% 							pend.kc2 = 2630.3;
%                                 
%                           % From gradient descent model fit: BNS 6/19/08
%                           pend.kcn = 1.393864914045661e+003;
% 							pend.kc1 = 1.640088148908839e+003;
% 							pend.kc2 = 2.500420060759658e+003;
                                
							% Solved for exactly using the measured masses
							% and resonance frequencies. See matlab code spring_stiffness_calc.m: BNS 6/19/08
                            pend.kcn = 1411.4640262910420948351545480224;%1454.3002595787734522877843898600;%1354.4781888292937115945272311686;
							pend.kc1 = 1650.5240590453796728792143217792;%1675.2246951035885218136723875577;%1624.3828291240573009596189209666;
							pend.kc2 = 2423.5190152802382310519860608100;%2378.4768871885927774179263915596;%2548.8310078998871176535405118386;
                            
                            pend.kxn = 1.0*10^5;  % as for middle 
                            pend.kx1 = 1.0*10^5;  % Justin 11/29/05 
                            pend.kx2 = 0.8*10^5;%6.5630e+004;  % Ian 12/09/05 
                            
                            % Added to pend structure definition for
                            % convenience of d's. BNS 6/18/2008
                            pend.mn3 = pend.mn+pend.m1+pend.m2+pend.m3;
                            pend.m13 = pend.m1+pend.m2+pend.m3;
                            pend.m23 = pend.m2+pend.m3;
                            pend.cn=(pend.ln^2-(pend.nn1-pend.nn0)^2)^0.5/pend.ln;	%cos(omegan)
                            pend.c1=(pend.l1^2-(pend.n1-pend.n0)^2)^0.5/pend.l1;	%cos(omega1)
                            pend.c2=(pend.l2^2-(pend.n3-pend.n2)^2)^0.5/pend.l2;	%cos(omega2)
                            pend.c3=(pend.l3^2-(pend.n5-pend.n4)^2)^0.5/pend.l3;	%cos(omega3)
                            pend.flexn = sqrt(2*((1/4)*pi*pend.rn^4)*pend.Yn/pend.mn3/pend.g)*pend.cn^(3/2); % flexn = 0.004534992483623; 
                            pend.flex1 = sqrt(4*((1/4)*pi*pend.r1^4)*pend.Y1/pend.m13/pend.g)*pend.c1^(3/2); % flex1 = 0.002747104240021; 
                            pend.flex2 = sqrt(4*((1/4)*pi*pend.r2^4)*pend.Y2/pend.m23/pend.g)*pend.c2^(3/2); % flex2 = 0.002926142794287; 
                            pend.flex3 = sqrt(4*((1/4)*pi*pend.r3^4)*pend.Y3/pend.m3/pend.g)*pend.c3^(3/2); % flex3 = 0.002163035309137; for long/pitch, yaw and vertical
                            
                            %d correction for lateral blade compliance.
                            %Added to pend structure definition for
                            %convenience of d's. BNS 6/18/2008
                            pend.bend1 = pend.g*(pend.m1+pend.m2+pend.m3)/(2*pend.kx1);
                            pend.bend2 = pend.g*(pend.m2+pend.m3)/(2*pend.kx2);
                            
                             pend.dm = (1 + 0) / 1000 - pend.flexn; % BNS 6/18/08
                             pend.dn = (1 + 0) / 1000 - pend.flex1 + pend.bend1;% - (0.0015-0.00084838); % BNS 6/18/08
                             pend.d0 = (1 + 0) / 1000 - pend.flex1; % BNS 6/18/08
                             pend.d1 = (1 + 0) / 1000 - pend.flex2 + pend.bend2;% - (0.0015+0.00075939); % BNS 6/18/08 
                             pend.d2 = 10.82   / 1000 - pend.flex2; % Physical d is 8.02 [mm] D0901346-v9, flex correction is 2.93 [mm] = 10.94 [mm] ~ 11 [mm], but we'll assume Brett fit measurements to get 10.82 [mm] effective. M. Barton J. Kissel
                             pend.d3 = (1 + 0) / 1000 - pend.flex3; % BNS 6/18/08  
                             pend.d4 = 0; % Prisms for ERMs and TCPs were glued with Physical d on centerline E1000752
                             
                         pend.stage2 = 1;
